@@ -174,7 +174,7 @@ sim_ays_covar <- function(sd = 2.8, range = 300, lambda = 1, model = "matern",
 #' parabola_fun <- sim_parabola(mu = 50, sigma = 5, plot = TRUE)
 #' parabola_fun(x = 0:100)
 #'
-#' parabola_fun <- sim_parabola(mu = log(40), sigma = 0.5, log_space = TRUE, plot = TRUE)
+#' parabola_fun <- sim_parabola(mu = log(40), sigma = 0.5, log_space = FALSE, plot = TRUE)
 #' parabola_fun(x = 1:1000)
 #'
 #' parabola_fun <- sim_parabola(mu = c(50, 120), sigma = c(5, 3), plot = TRUE)
@@ -215,7 +215,6 @@ sim_parabola <- function(alpha = 0, mu = 200, sigma = 70, sigma_right = NULL,
       plot(x, y, main = "sim_parabola", col = i)
     }
 
-    plot_ly(x = x, y = exp(y)) %>% add_lines()
     y
 
   }
@@ -254,7 +253,7 @@ sim_parabola <- function(alpha = 0, mu = 200, sigma = 70, sigma_right = NULL,
 #' @examples
 #'
 #' sim <- sim_abundance(ages = 1:10, years = 1:10) %>%
-#'            sim_distribution(grid = make_grid(res = c(10, 10)),
+#'            sim_distribution(grid = make_grid(res = c(12, 12)),
 #'                             ays_covar = sim_ays_covar(phi_age = 0.8,
 #'                                                       phi_year = 0.1),
 #'                             depth_par = sim_parabola(mu = 200,
@@ -299,6 +298,10 @@ sim_distribution <- function(sim,
   prob <- apply(prob, c(1, 2), function(x) { x / sum(x) })
   prob <- aperm(prob, c(2, 3, 1))
 
+  if (any(is.nan(prob))) {
+    stop("NaN values were produced when running sim_distribution. This problem was most likely caused by the effect supplied to the depth_par agument. Please ensure that the closure supplied is not producing extremely low values that effectively translate to zero when exponentiated. This problem can arise when, for example, values in log space are used in sim_parabola, but log_space = FALSE.")
+  }
+
   ## Distribute fish through the cells
   N <- replicate(nrow(grid_dat), sim$N)
   dimnames(N) <- dimnames(prob)
